set verify off

DROP TABLE HOSPITAL CASCADE CONSTRAINTS;

CREATE TABLE HOSPITAL (
 HOSPITAL_COD   NUMBER(2) CONSTRAINT HOSPITAL_PK PRIMARY KEY,
 NOM            VARCHAR2(10) CONSTRAINT HOSPITAL_NN_NOM NOT NULL,
 DOMICILI       VARCHAR2(20),
 TELEFON        VARCHAR2(8),
 QTAT_LLITS     NUMBER(3) DEFAULT 0
                          CONSTRAINT HOSPITAL_CK_LLITS CHECK (QTAT_LLITS >=0));

CREATE INDEX HOSPITAL_NOM ON HOSPITAL (NOM);

PAUSE "Hem creat la taula HOSPITAL. Ara hi inserirem valors. Premi tecla..."

INSERT INTO HOSPITAL VALUES (13,'Provincial','O Donell 50','964-4264',0);
INSERT INTO HOSPITAL VALUES (18,'General','Atocha s/n','595-3111',0);
INSERT INTO HOSPITAL VALUES (22,'La Paz','Castellana 1000','923-5411',0);
INSERT INTO HOSPITAL VALUES (45,'San Carlos','Ciudad Universitaria',
'597-1500',0);
COMMIT;

PAUSE "Hem inserit valors a la taula HOSPITAL. Premi tecla..."

DROP TABLE SALA CASCADE CONSTRAINTS;

CREATE TABLE SALA (
 HOSPITAL_COD  NUMBER(2) CONSTRAINT SALA_FK_HOSPITAL REFERENCES HOSPITAL,
 SALA_COD      NUMBER(2),
 NOM           VARCHAR2(20) CONSTRAINT SALA_NN_NOM NOT NULL,
 QTAT_LLITS    NUMBER(3) DEFAULT 0
                         CONSTRAINT SALA_CK_LLITS CHECK (QTAT_LLITS >=0),
 CONSTRAINT SALA_PK PRIMARY KEY (HOSPITAL_COD, SALA_COD)) ;

CREATE INDEX "SALA_HOSP+NOM" ON SALA (HOSPITAL_COD, NOM);

PAUSE "Hem creat la taula SALA. Ara hi inserirem valors. Premi tecla..."

INSERT INTO SALA VALUES (13,3,'Cures Intensives',21);
INSERT INTO SALA VALUES (13,6,'Psiquitric',67);
INSERT INTO SALA VALUES (18,3,'Cures Intensives',10);
INSERT INTO SALA VALUES (18,4,'Cardiologia',53);
INSERT INTO SALA VALUES (22,1,'Recuperaci',10);
INSERT INTO SALA VALUES (22,6,'Psiquitric',118);
INSERT INTO SALA VALUES (22,2,'Maternitat',34);
INSERT INTO SALA VALUES (45,4,'Cardiologia',55);
INSERT INTO SALA VALUES (45,1,'Recuperaci',13);
INSERT INTO SALA VALUES (45,2,'Maternitat',24);
COMMIT;

PAUSE "Hem inserit valors a la taula SALA. Premi tecla..."

UPDATE HOSPITAL 
SET QTAT_LLITS = (SELECT SUM(QTAT_LLITS) 
                  FROM SALA 
                  WHERE HOSPITAL.HOSPITAL_COD = SALA. HOSPITAL_COD);

PAUSE "Hem recalculat els llits dels hospitals en funci dels llits assignats a cada sala. Premi tecla..."

DROP TABLE PLANTILLA CASCADE CONSTRAINTS;

CREATE TABLE PLANTILLA (
 HOSPITAL_COD  NUMBER(2),
 SALA_COD      NUMBER(2),
 EMPLEAT_NO    NUMBER(4) CONSTRAINT PLANTILLA_NN_EMPLEAT NOT NULL,
 COGNOM        VARCHAR2(15) CONSTRAINT PLANTILLA_NN_COGNOM NOT NULL,
 FUNCIO        VARCHAR2(10), 
 TORN          VARCHAR2(1) CONSTRAINT PLANTILLA_CK_TORN CHECK (TORN IN ('M','T','N')),
 SALARI        NUMBER(10),
 CONSTRAINT PLANTILLA_FK_SALA FOREIGN KEY (HOSPITAL_COD, SALA_COD) REFERENCES SALA,
 CONSTRAINT PLANTILLA_PK PRIMARY KEY (HOSPITAL_COD, SALA_COD, EMPLEAT_NO)) ;  

CREATE INDEX "PLANTILLA_HOSP+COGNOM" ON PLANTILLA (HOSPITAL_COD, COGNOM);
CREATE INDEX "PLANTILLA_HOSP+FUNCIO" ON PLANTILLA (HOSPITAL_COD, FUNCIO);
CREATE INDEX "PLANTILLA_FUNCIO+HOSP+SALA" ON PLANTILLA (FUNCIO, HOSPITAL_COD, SALA_COD);

PAUSE "Hem creat la taula PLANTILA. Ara hi inserirem valors. Premi tecla..."

INSERT INTO PLANTILLA VALUES(13,6,3754,'Daz B.','Infermera','T',2262000);
INSERT INTO PLANTILLA VALUES(13,6,3106,'Hernndez J.','Infermer','T',2755000); 
INSERT INTO PLANTILLA VALUES(18,4,6357,'Karplus W.','Intern','T',3379000);
INSERT INTO PLANTILLA VALUES(22,6,1009,'Higueras D.','Infermera','T',2005000);
INSERT INTO PLANTILLA VALUES(22,6,8422,'Bocina G.','Infermer','M',1638000);
INSERT INTO PLANTILLA VALUES(22,2,9901,'Adams C.','Intern','M',2210000);
INSERT INTO PLANTILLA VALUES(22,1,6065,'Rivera G.','Infermera','N',1626000);
INSERT INTO PLANTILLA VALUES(22,1,7379,'Carlos R.','Infermera','T',2119000);
INSERT INTO PLANTILLA VALUES(45,4,1280,'Amig R.','Intern','N',2210000);
INSERT INTO PLANTILLA VALUES(45,1,8526,'Frank H.','Infermera','T',2522000);
COMMIT;

PAUSE "Hem inserit valors a la taula PLANTILLA. Premi tecla..."

DROP TABLE MALALT CASCADE CONSTRAINTS;

CREATE TABLE MALALT (
 INSCRIPCIO    NUMBER(5) CONSTRAINT MALALT_PK PRIMARY KEY,  
 COGNOM        VARCHAR2(15) CONSTRAINT MALALT_NN_COGNOM NOT NULL,
 DOMICILI      VARCHAR2(20),
 DATA_NAIX     DATE,
 SEXE          VARCHAR2(1) CONSTRAINT MALALT_NN_SEXE NOT NULL
                           CONSTRAINT MALALT_CK_SEXE CHECK (SEXE = 'H' OR SEXE = 'D'),
 NSS           NUMBER(9)) ;

CREATE INDEX "MALALT_NAIX+COGNOM" ON MALALT (DATA_NAIX, COGNOM);
CREATE INDEX "MALALT_COGNOM+NAIX" ON MALALT (COGNOM, DATA_NAIX);

PAUSE "Hem creat la taula MALALT. Ara hi inserirem valors. Premi tecla..."

INSERT INTO MALALT VALUES(10995,'Lagua M.','Goya 20',
to_date('16/05/1956', 'dd/mm/yyyy'),'H',280862482);
INSERT INTO MALALT VALUES(18004,'Serrano V.','Alcala 12',
to_date('21/05/1960', 'dd/mm/yyyy'),'D',284991452);
INSERT INTO MALALT VALUES(14024,'Fernndez M.','Recoletos 50',
to_date('23/06/1967', 'dd/mm/yyyy'),'D',321790059);
INSERT INTO MALALT VALUES(36658,'Domin S.','Mayor 71',
to_date('01/01/1942', 'dd/mm/yyyy'),'H',160657471);
INSERT INTO MALALT VALUES(38702,'Neal R.','Orense 11',
to_date('18/06/1940', 'dd/mm/yyyy'),'D',380010217);
INSERT INTO MALALT VALUES(39217,'Cervantes M.','Peron 38',
to_date('29/02/1952', 'dd/mm/yyyy'),'H',440294390);
INSERT INTO MALALT VALUES(59076,'Miller G.','Lopez de Hoyos 2',
to_date('16/09/1945', 'dd/mm/yyyy'),'D',311969044);
INSERT INTO MALALT VALUES(63827,'Ruz P.','Esquerdo 103',
to_date('26/12/1980', 'dd/mm/yyyy'),'H',100973253);
INSERT INTO MALALT VALUES(64823,'Fraser A.','Soto 3',
to_date('10/07/1980', 'dd/mm/yyyy'),'D',285201776);
INSERT INTO MALALT VALUES(74835,'Bentez E.','Argentina 5',
to_date('05/10/1957', 'dd/mm/yyyy'),'H',154811767);
COMMIT;

PAUSE "Hem inserit valors a la taula MALALT. Premi tecla..."

DROP TABLE INGRESSOS CASCADE CONSTRAINTS;

CREATE TABLE INGRESSOS (
 INSCRIPCIO    NUMBER(5) CONSTRAINT INGRESSOS_PK PRIMARY KEY
                         CONSTRAINT INGRESSOS_FK_MALALT REFERENCES MALALT,
 HOSPITAL_COD  NUMBER(2) CONSTRAINT INGRESSOS_NN_HOSPITAL NOT NULL,
 SALA_COD      NUMBER(2) CONSTRAINT INGRESSOS_NN_SALA NOT NULL,
 LLIT          NUMBER(4) CONSTRAINT INGRESSOS_CK_LLIT CHECK (LLIT > 0),
 CONSTRAINT INGRESSOS_FK_SALA FOREIGN KEY (HOSPITAL_COD, SALA_COD) REFERENCES SALA);

CREATE INDEX "INGRESSOS_HOSP+SALA" ON INGRESSOS (HOSPITAL_COD, SALA_COD);

PAUSE "Hem creat la taula INGRESSOS. Ara hi inserirem valors. Premi tecla..."

INSERT INTO INGRESSOS VALUES(10995,13,3,1);
INSERT INTO INGRESSOS VALUES(18004,13,3,2);
INSERT INTO INGRESSOS VALUES(14024,13,3,3);
INSERT INTO INGRESSOS VALUES(36658,18,4,1);
INSERT INTO INGRESSOS VALUES(38702,18,4,2);
INSERT INTO INGRESSOS VALUES(39217,22,6,1);
INSERT INTO INGRESSOS VALUES(59076,22,6,2);
INSERT INTO INGRESSOS VALUES(63827,22,6,3);
INSERT INTO INGRESSOS VALUES(64823,22,2,1);
COMMIT;

PAUSE "Hem inserit valors a la taula INGRESSOS. Premi tecla..."

DROP TABLE DOCTOR CASCADE CONSTRAINTS;

CREATE TABLE DOCTOR (
 HOSPITAL_COD  NUMBER(2) CONSTRAINT DOCTOR_FK_HOSPITAL REFERENCES HOSPITAL,
 DOCTOR_NO     NUMBER(3),
 COGNOM        VARCHAR2(13) CONSTRAINT DOCTOR_NN_COGNOM NOT NULL,
 ESPECIALITAT  VARCHAR2(16) CONSTRAINT DOCTOR_NN_ESPECIALITAT NOT NULL,
 CONSTRAINT DOCTOR_PK PRIMARY KEY (HOSPITAL_COD, DOCTOR_NO)) ;

PAUSE "Hem creat la taula DOCTOR. Ara hi inserirem valors. Premi tecla..."

INSERT INTO DOCTOR VALUES(13,435,'Lpez A.','Cardiologia');
INSERT INTO DOCTOR VALUES(18,585,'Miller G.','Ginecologia');
INSERT INTO DOCTOR VALUES(18,982,'Cajal R.','Cardiologia');
INSERT INTO DOCTOR VALUES(22,453,'Galo D.','Pediatria');
INSERT INTO DOCTOR VALUES(22,398,'Best K.','Urologia');
INSERT INTO DOCTOR VALUES(22,386,'Cabeza D.','Psiquiatria');
INSERT INTO DOCTOR VALUES(45,607,'Nico P.','Pediatria');
INSERT INTO DOCTOR VALUES(45,522,'Adams C.','Neurologia');
COMMIT;

CREATE INDEX "DOCTOR_ESP+HOSP" ON DOCTOR (ESPECIALITAT, HOSPITAL_COD);
CREATE INDEX "DOCTOR_HOSP+ESP" ON DOCTOR (HOSPITAL_COD, ESPECIALITAT);

PAUSE "Hem inserit valors a la taula DOCTOR. Premi tecla..."

PAUSE "El gui s'ha executat correctament. Premi tecla..."
